@@ -49,12 +49,19 @@
 
 package com.openexchange.admin.reseller.rmi.impl;
 
+import static com.openexchange.admin.rmi.exceptions.RemoteExceptionUtils.convertException;
+import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.java.Autoboxing.i;
 import java.rmi.RemoteException;
+import java.util.ArrayList;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import com.openexchange.admin.daemons.ClientAdminThread;
+import com.openexchange.admin.plugins.PluginException;
 import com.openexchange.admin.reseller.daemons.ClientAdminThreadExtended;
+import com.openexchange.admin.reseller.plugins.OXResellerPluginInterface;
 import com.openexchange.admin.reseller.rmi.OXResellerInterface;
 import com.openexchange.admin.reseller.rmi.OXResellerTools;
 import com.openexchange.admin.reseller.rmi.OXResellerTools.ClosureInterface;
@@ -62,6 +69,7 @@ import com.openexchange.admin.reseller.rmi.dataobjects.ResellerAdmin;
 import com.openexchange.admin.reseller.rmi.dataobjects.Restriction;
 import com.openexchange.admin.reseller.rmi.exceptions.OXResellerException;
 import com.openexchange.admin.reseller.rmi.exceptions.OXResellerException.Code;
+import com.openexchange.admin.reseller.services.PluginInterfaces;
 import com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface;
 import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
@@ -75,7 +83,7 @@ import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.admin.tools.GenericChecks;
 
 /**
- * @author choeger
+ * @author <a href="mailto:carsten.hoeger@open-xchange.com">Carsten Hoeger</a>
  */
 public class OXReseller extends OXCommonImpl implements OXResellerInterface {
 
@@ -94,7 +102,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
         resellerauth = new ResellerAuth();
         try {
             oxresell = OXResellerStorageInterface.getInstance();
-        } catch (final StorageException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
         }
@@ -104,19 +112,19 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
     public void change(final ResellerAdmin adm, final Credentials creds) throws RemoteException, InvalidDataException, StorageException, OXResellerException, InvalidCredentialsException {
         try {
             doNullCheck(adm);
-        } catch (final InvalidDataException e) {
+        } catch (InvalidDataException e) {
             LOGGER.error("Invalid data sent by client!", e);
             throw e;
         }
 
         try {
-            int pid = 0;
+            ResellerAdmin parent = null;
             final Credentials masterCredentials = cache.getMasterCredentials();
-            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
+            if ( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
                 basicauth.doAuthentication(creds);
             } else {
                 resellerauth.doAuthentication(creds);
-                pid = oxresell.getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0].getId().intValue();
+                parent = oxresell.getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0];
                 if (adm.getParentId() != null ) {
                     throw new OXResellerException(Code.SUBAMIN_NOT_ALLOWED_TO_CHANGE_PARENTID);
                 }
@@ -130,30 +138,31 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
 
             GenericChecks.checkChangeValidPasswordMech(adm);
 
-            // if no password mech supplied, use the old one as set in db
             final ResellerAdmin dbadm = oxresell.getData(new ResellerAdmin[] { adm })[0];
-            if( pid > 0 && dbadm.getParentId().intValue() != pid ) {
+            if (null != parent && false == dbadm.getParentId().equals(parent.getId())) {
                 LOGGER.error("unathorized access to {} by {}", dbadm.getName(), creds.getLogin());
                 throw new InvalidCredentialsException("authentication failed");
             }
+            // if no password mech supplied, use the old one as set in db
             if (adm.getPasswordMech() == null) {
                 adm.setPasswordMech(dbadm.getPasswordMech());
             }
 
-            final Integer parentId = adm.getParentId();
-            if ( parentId != null && 0 != parentId.intValue() ) {
-                if( !oxresell.existsAdmin(new ResellerAdmin(adm.getParentId().intValue())) ) {
-                    throw new OXResellerException(Code.RESELLER_ADMIN_NOT_EXIST, "with parentId=" + adm.getParentId());
+            final Integer changedParentId = adm.getParentId();
+            if ( changedParentId != null && 0 != changedParentId.intValue() ) {
+                if (!oxresell.existsAdmin(new ResellerAdmin(i(changedParentId)))) {
+                    throw new OXResellerException(Code.RESELLER_ADMIN_NOT_EXIST, "with parentId=" + changedParentId);
                 }
-                final ResellerAdmin parentAdmin = oxresell.getData(new ResellerAdmin[]{new ResellerAdmin(adm.getParentId().intValue())})[0];
-                if( parentAdmin.getParentId().intValue() > 0 ) {
+                final ResellerAdmin changedParentAdmin = oxresell.getData(new ResellerAdmin[] { new ResellerAdmin(i(changedParentId)) })[0];
+                if ( changedParentAdmin.getParentId().intValue() > 0 ) {
                     throw new OXResellerException(Code.CANNOT_SET_PARENTID_TO_SUBSUBADMIN);
                 }
+                parent = changedParentAdmin;
             }
 
             Restriction[] res = adm.getRestrictions();
-            if( res != null ) {
-                if( res.length > 0 && dbadm.getParentId().intValue() > 0 ) {
+            if ( res != null ) {
+                if ( res.length > 0 && dbadm.getParentId().intValue() > 0 ) {
                     throw new OXResellerException(Code.SUBSUBADMIN_NOT_ALLOWED_TO_CHANGE_RESTRICTIONS);
                 }
             }
@@ -170,22 +179,66 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
             }
 
             checkRestrictionsPerSubadmin(adm);
+
+            adm.setParentId(null != parent ? parent.getId() : I(0));
+            adm.setParentName(null != parent ? parent.getName() : null);
+
+            
+            // Trigger plugin extensions
+            {
+                final PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
+                if (null != pluginInterfaces) {
+                    for (final OXResellerPluginInterface oxresellpi : pluginInterfaces.getResellerPlugins().getServiceList()) {
+                        try {
+                            LOGGER.debug("Calling beforeChange for plugin: {}", oxresellpi.getClass().getName());
+                            oxresellpi.beforeChange(adm, creds);
+                        } catch (PluginException e) {
+                            LOGGER.error("Error while calling beforeChange for plugin: {}", oxresellpi.getClass().getName(), e);
+                            throw StorageException.wrapForRMI(e);
+                        } catch (RuntimeException e) {
+                            LOGGER.error("Error while calling beforeChange for plugin: {}", oxresellpi.getClass().getName(), e);
+                            throw StorageException.wrapForRMI(e);
+                        }
+                    }
+                }
+            }
+
             oxresell.change(adm);
-        } catch (final InvalidDataException e) {
+
+            // Trigger plugin extensions
+            {
+                final PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
+                if (null != pluginInterfaces) {
+                    for (final OXResellerPluginInterface oxresellpi : pluginInterfaces.getResellerPlugins().getServiceList()) {
+                        try {
+                            LOGGER.debug("Calling change for plugin: {}", oxresellpi.getClass().getName());
+                            oxresellpi.change(adm, creds);
+                        } catch (PluginException e) {
+                            LOGGER.error("Error while calling change for plugin: {}", oxresellpi.getClass().getName(), e);
+                            throw StorageException.wrapForRMI(e);
+                        } catch (RuntimeException e) {
+                            LOGGER.error("Error while calling change for plugin: {}", oxresellpi.getClass().getName(), e);
+                            throw StorageException.wrapForRMI(e);
+                        }
+                    }
+                }
+            }
+
+        } catch (InvalidDataException e) {
             LOGGER.error("Invalid data sent by client!", e);
             throw e;
-        } catch (final StorageException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final OXResellerException e) {
+        } catch (OXResellerException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final RuntimeException e) {
+        } catch (RuntimeException e) {
             LOGGER.error("", e);
-            throw e;
+            throw convertException(e);
         }
     }
 
@@ -193,14 +246,15 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
     public ResellerAdmin create(final ResellerAdmin adm, final Credentials creds) throws RemoteException, InvalidDataException, StorageException, InvalidCredentialsException, OXResellerException {
         try {
             doNullCheck(adm);
-        } catch (final InvalidDataException e) {
+        } catch (InvalidDataException e) {
             LOGGER.error("Invalid data sent by client!", e);
             throw e;
         }
-        int pid = 0;
         try {
+            ResellerAdmin parent = null;
+
             final Credentials masterCredentials = cache.getMasterCredentials();
-            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
+            if ( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
                 basicauth.doAuthentication(creds);
             } else {
                 resellerauth.doAuthentication(creds);
@@ -210,9 +264,9 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
                     true,
                     Restriction.SUBADMIN_CAN_CREATE_SUBADMINS,
                     Restriction.MAX_SUBADMIN_PER_SUBADMIN
-                );
-                if( oxresell.existsAdmin(new ResellerAdmin(creds.getLogin(), creds.getPassword())) ) {
-                    pid = oxresell.getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0].getId().intValue();
+                    );
+                if ( oxresell.existsAdmin(new ResellerAdmin(creds.getLogin(), creds.getPassword())) ) {
+                    parent = oxresell.getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0];
                 }
             }
 
@@ -229,32 +283,68 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
             }
 
             Restriction[] res = adm.getRestrictions();
-            if( res != null ) {
-                if( res.length > 0 && pid > 0 ) {
+            if ( res != null ) {
+                if ( res.length > 0 && null != parent ) {
                     throw new OXResellerException(Code.SUBSUBADMIN_NOT_ALLOWED_TO_CHANGE_RESTRICTIONS);
                 }
             }
 
-            adm.setParentId(Integer.valueOf(pid));
+            adm.setParentId(null != parent ? parent.getId() : I(0));
+            adm.setParentName(null != parent ? parent.getName() : null);
 
             checkRestrictionsPerSubadmin(adm);
 
-            return oxresell.create(adm);
-        } catch (final StorageException e) {
+            ResellerAdmin ra = oxresell.create(adm);
+
+
+            // Trigger plugin extensions
+            {
+                final List<OXResellerPluginInterface> interfacelist = new ArrayList<OXResellerPluginInterface>();
+                final PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
+                if (null != pluginInterfaces) {
+                    for (final OXResellerPluginInterface oxresellpi : pluginInterfaces.getResellerPlugins().getServiceList()) {
+                        final String bundlename = oxresellpi.getClass().getName();
+                        try {
+                            LOGGER.debug("Calling create for plugin: {}", bundlename);
+                            oxresellpi.create(ra, creds);
+                            interfacelist.add(oxresellpi);
+                        } catch (PluginException e) {
+                            LOGGER.error("Error while calling create for plugin: {}", bundlename, e);
+                            LOGGER.info("Now doing rollback for everything until now...");
+                            for (final OXResellerPluginInterface oxresellerinterface : interfacelist) {
+                                try {
+                                    oxresellerinterface.delete(adm, creds);
+                                } catch (PluginException e1) {
+                                    LOGGER.error("Error doing rollback for plugin: {}", bundlename, e1);
+                                }
+                            }
+                            try {
+                                oxresell.delete(adm);
+                            } catch (StorageException e1) {
+                                LOGGER.error("Error rolling back reseller creation in database", e1);
+                            }
+                            throw StorageException.wrapForRMI(e);
+                        }
+                    }
+                }
+            }
+
+            return ra;
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final OXResellerException e) {
+        } catch (OXResellerException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final EnforceableDataObjectException e) {
+        } catch (EnforceableDataObjectException e) {
             LOGGER.error("", e);
             throw new InvalidDataException(e.getMessage());
-        } catch (final RuntimeException e) {
+        } catch (RuntimeException e) {
             LOGGER.error("", e);
-            throw e;
+            throw convertException(e);
         }
     }
 
@@ -262,7 +352,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
     public void delete(final ResellerAdmin adm, final Credentials creds) throws RemoteException, InvalidDataException, StorageException, OXResellerException, InvalidCredentialsException {
         try {
             doNullCheck(adm);
-        } catch (final InvalidDataException e) {
+        } catch (InvalidDataException e) {
             LOGGER.error("Invalid data sent by client!", e);
             throw e;
         }
@@ -270,7 +360,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
         try {
             boolean isMaster = false;
             final Credentials masterCredentials = cache.getMasterCredentials();
-            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
+            if ( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
                 basicauth.doAuthentication(creds);
                 isMaster = true;
             } else {
@@ -282,50 +372,71 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
             if (!oxresell.existsAdmin(adm)) {
                 throw new OXResellerException(Code.RESELLER_ADMIN_NOT_EXIST, adm.getName());
             }
-            if(! isMaster ) {
-                ResellerAdmin sadmdata = oxresell.getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0];
-                ResellerAdmin dadmdata = oxresell.getData(new ResellerAdmin[] { adm })[0];
-                if( !dadmdata.getParentId().equals(sadmdata.getId()) ) {
-                    throw new OXResellerException(Code.SUBADMIN_DOES_NOT_BELONG_TO_SUBADMIN, dadmdata.getName(), sadmdata.getName());
+
+            final ResellerAdmin dbadm = oxresell.getData(new ResellerAdmin[] { adm })[0];
+            ResellerAdmin parent = null;
+            if (! isMaster ) {
+                parent = oxresell.getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0];
+                if ( !dbadm.getParentId().equals(parent.getId()) ) {
+                    throw new OXResellerException(Code.SUBADMIN_DOES_NOT_BELONG_TO_SUBADMIN, dbadm.getName(), parent.getName());
                 }
             }
-            if (adm.getName() == null) {
-                if (oxresell.ownsContext(null, adm.getId().intValue())) {
-                    throw new OXResellerException(Code.UNABLE_TO_DELETE, adm.getId().toString());
-                }
-            } else {
-                if (oxresell.checkOwnsContextAndSetSid(null, new Credentials(adm.getName(), null))) {
-                    throw new OXResellerException(Code.UNABLE_TO_DELETE, adm.getName());
+
+            if (oxresell.ownsContext(null, dbadm.getId().intValue())) {
+                throw new OXResellerException(Code.UNABLE_TO_DELETE, dbadm.getId().toString());
+            }
+
+            dbadm.setParentName(null != parent ? parent.getName() : null);
+
+            final ArrayList<OXResellerPluginInterface> interfacelist = new ArrayList<OXResellerPluginInterface>();
+
+            // Trigger plugin extensions
+            {
+                final PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
+                if (null != pluginInterfaces) {
+                    for (final OXResellerPluginInterface oxresellpi : pluginInterfaces.getResellerPlugins().getServiceList()) {
+                        final String bundlename = oxresellpi.getClass().getName();
+                        try {
+                            LOGGER.debug("Calling delete for plugin: {}", bundlename);
+                            oxresellpi.delete(dbadm, creds);
+                            interfacelist.add(oxresellpi);
+                        } catch (PluginException e) {
+                            LOGGER.error("Error while calling delete for plugin: {}", bundlename, e);
+                            throw StorageException.wrapForRMI(e);
+                        }
+                    }
                 }
             }
-            oxresell.delete(adm);
-        } catch (final InvalidDataException e) {
+
+
+            oxresell.delete(dbadm);
+        } catch (InvalidDataException e) {
             LOGGER.error("Invalid data sent by client!", e);
             throw e;
-        } catch (final StorageException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final OXResellerException e) {
+        } catch (OXResellerException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final RuntimeException e) {
+        } catch (RuntimeException e) {
             LOGGER.error("", e);
-            throw e;
+            throw convertException(e);
         }
     }
 
     @Override
-    public Restriction[] getAvailableRestrictions(final Credentials creds) throws InvalidCredentialsException, StorageException, OXResellerException {
+    public Restriction[] getAvailableRestrictions(final Credentials creds) throws RemoteException, InvalidCredentialsException, StorageException, OXResellerException {
         if (null == creds) {
             throw new InvalidCredentialsException("Credentials are missing.");
         }
 
         try {
             final Credentials masterCredentials = cache.getMasterCredentials();
-            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin())) {
+            if ( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin())) {
                 basicauth.doAuthentication(creds);
             } else {
                 resellerauth.doAuthentication(creds);
@@ -341,12 +452,12 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
                 ret.add(entry.getValue());
             }
             return ret.toArray(new Restriction[ret.size()]);
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final RuntimeException e) {
+        } catch (RuntimeException e) {
             LOGGER.error("", e);
-            throw e;
+            throw convertException(e);
         }
     }
 
@@ -362,7 +473,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
             if (admins.length <= 0) {
                 throw new InvalidDataException();
             }
-        } catch (final InvalidDataException e) {
+        } catch (InvalidDataException e) {
             LOGGER.error("Invalid data sent by client!", e);
             throw e;
         }
@@ -370,7 +481,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
         try {
             int pid = 0;
             final Credentials masterCredentials = cache.getMasterCredentials();
-            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
+            if ( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
                 basicauth.doAuthentication(creds);
             } else {
                 resellerauth.doAuthentication(creds);
@@ -385,21 +496,21 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
             }
 
             return oxresell.getData(admins);
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final InvalidDataException e) {
+        } catch (InvalidDataException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final StorageException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final OXResellerException e) {
+        } catch (OXResellerException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final RuntimeException e) {
+        } catch (RuntimeException e) {
             LOGGER.error("", e);
-            throw e;
+            throw convertException(e);
         }
 
     }
@@ -409,7 +520,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
         try {
             doNullCheck(ctx);
             doNullCheck(ctx.getId());
-        } catch (final InvalidDataException e) {
+        } catch (InvalidDataException e) {
             LOGGER.error("Invalid data sent by client!", e);
             throw e;
         }
@@ -427,20 +538,20 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
             }
 
             return oxresell.getRestrictionsFromContext(ctx);
-        } catch (final StorageException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final RuntimeException e) {
+        } catch (RuntimeException e) {
             LOGGER.error("", e);
-            throw e;
+            throw convertException(e);
         }
     }
 
     @Override
-    public void initDatabaseRestrictions(final Credentials creds) throws StorageException, InvalidCredentialsException, OXResellerException {
+    public void initDatabaseRestrictions(final Credentials creds) throws RemoteException, StorageException, InvalidCredentialsException, OXResellerException {
         try {
             basicauth.doAuthentication(creds);
             final Map<String, Restriction> validRestrictions = oxresell.listRestrictions("*");
@@ -448,18 +559,18 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
                 throw new OXResellerException(Code.DATABASE_ALREADY_CONTAINS_RESTRICTIONS);
             }
             oxresell.initDatabaseRestrictions();
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final StorageException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final OXResellerException e) {
+        } catch (OXResellerException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final RuntimeException e) {
+        } catch (RuntimeException e) {
             LOGGER.error("", e);
-            throw e;
+            throw convertException(e);
         }
     }
 
@@ -467,29 +578,29 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
     public ResellerAdmin[] list(final String search_pattern, final Credentials creds) throws RemoteException, InvalidDataException, StorageException, InvalidCredentialsException {
         try {
             doNullCheck(search_pattern);
-        } catch (final InvalidDataException e) {
+        } catch (InvalidDataException e) {
             LOGGER.error("Invalid data sent by client!", e);
             throw e;
         }
 
         try {
             final Credentials masterCredentials = cache.getMasterCredentials();
-            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
+            if ( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
                 basicauth.doAuthentication(creds);
                 return oxresell.list(search_pattern);
             }
             resellerauth.doAuthentication(creds);
             int pid = oxresell.getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0].getId().intValue();
             return oxresell.list(search_pattern, pid);
-        } catch (final StorageException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final RuntimeException e) {
+        } catch (RuntimeException e) {
             LOGGER.error("", e);
-            throw e;
+            throw convertException(e);
         }
     }
 
@@ -503,18 +614,18 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
             }
 
             oxresell.removeDatabaseRestrictions();
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final StorageException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final OXResellerException e) {
+        } catch (OXResellerException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final RuntimeException e) {
+        } catch (RuntimeException e) {
             LOGGER.error("", e);
-            throw e;
+            throw convertException(e);
         }
     }
 
@@ -529,18 +640,18 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
             }
 
             oxresell.updateModuleAccessRestrictions();
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final StorageException e) {
-            LOGGER.error("", e);
-            throw e;
-        } catch (final RuntimeException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
         } catch (OXResellerException e) {
             LOGGER.error("", e);
             throw e;
+        } catch (RuntimeException e) {
+            LOGGER.error("", e);
+            throw convertException(e);
         }
     }
 
@@ -613,18 +724,18 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
             }
 
             oxresell.updateRestrictions();
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final StorageException e) {
-            LOGGER.error("", e);
-            throw e;
-        } catch (final RuntimeException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
         } catch (OXResellerException e) {
             LOGGER.error("", e);
             throw e;
+        } catch (RuntimeException e) {
+            LOGGER.error("", e);
+            throw convertException(e);
         }
     }
 
